<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 5/29/2012	ELL
// 
// 
// 
	
	include ("check_session.php");
	
	$class = $_POST['class'];
	$description = addslashes($_POST['description']);
	$style_sheet = $_POST['style_sheet'];
	$class_table = $style_sheet . "_classes";
	
	$replace = array(".", "#", " ", ",", ">", "&gt;", "+", "~");
	$search = array("PERIOD", "POUND", "SPACE", "COMMA", "GREATERTHAN", "GREATERTHAN", "PLUS", "TILDA");
	$class = str_replace($search, $replace, $class);
	
	$query = "UPDATE `" . BWB_TABLE_PREFIX . $class_table . "` SET `description`='" . $description. "' WHERE `class`='" . $class . "'";
	$cnt = $bwb_dbh->exec($query);
	
	if ($cnt < 0)
		echo "-no data-";
	else
		echo $cnt;

?>